==> ejc-procurement-api-3.0.0-20251204.045848-39-sources.jar: com/ejianc/business/procurement/plan/vo/ExecutePlanVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.procurement.plan.vo.ExecutePlanDetailVO;

/**
 * 采购执行计划
 * 
 * @author generator
 * 
 */
public class ExecutePlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal ctrlTaxMny; // 控制含税总额
    private BigDecimal preTaxMny; // 预估含税总额
    private BigDecimal bidTaxMny; // 投标含税总额
    private Date makeDate; // 编制日期
    private String billCode; // 执行计划编号
    private String orgName; // 采购实施单位名称
    private String orgCode; // 采购实施单位编码
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    private String employeeName; // 经办人名称
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    private String memo; // 备注
    private String name; // 执行计划名称
    private String purchaseType; // 采购方式：1-带量；2-入围；3-框架
    private String purchaseStage; // 入围阶段：1-一阶段；2-二阶段
    private String stageOneResultName; // 一阶段入围计划结果（参照定标结果）
    private String purchasePlanCode; // 一阶段采购计划编码
    private Integer billState; // 单据状态
    private Integer permissionType; // 实施流程 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private Integer abnormalStatus; // 计划异常状态 1-正常，2-取消采购，3-暂停采购
    private Long orgId; // 采购实施单位Id
    private Long employeeId; // 经办人
    private Long stageOneResultId; // 一阶段入围计划结果id（参照定标结果）
    private Long purchasePlanId; // 一阶段采购计划id
    
    private List<ExecutePlanDetailVO> executePlanDetailList = new ArrayList<>(); // 采购执行计划-明细

    public BigDecimal getCtrlTaxMny() {
        return ctrlTaxMny;
    }

    public void setCtrlTaxMny(BigDecimal ctrlTaxMny) {
        this.ctrlTaxMny = ctrlTaxMny;
    }
    public BigDecimal getPreTaxMny() {
        return preTaxMny;
    }

    public void setPreTaxMny(BigDecimal preTaxMny) {
        this.preTaxMny = preTaxMny;
    }
    public BigDecimal getBidTaxMny() {
        return bidTaxMny;
    }

    public void setBidTaxMny(BigDecimal bidTaxMny) {
        this.bidTaxMny = bidTaxMny;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseStage() {
        return purchaseStage;
    }

    public void setPurchaseStage(String purchaseStage) {
        this.purchaseStage = purchaseStage;
    }
    public String getStageOneResultName() {
        return stageOneResultName;
    }

    public void setStageOneResultName(String stageOneResultName) {
        this.stageOneResultName = stageOneResultName;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public Integer getAbnormalStatus() {
        return abnormalStatus;
    }

    public void setAbnormalStatus(Integer abnormalStatus) {
        this.abnormalStatus = abnormalStatus;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getStageOneResultId() {
        return stageOneResultId;
    }

    public void setStageOneResultId(Long stageOneResultId) {
        this.stageOneResultId = stageOneResultId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    
     public List<ExecutePlanDetailVO> getExecutePlanDetailList() {
        return executePlanDetailList;
     }

     public void setExecutePlanDetailList(List<ExecutePlanDetailVO> executePlanDetailList) {
        this.executePlanDetailList = executePlanDetailList;
     }
}

==> ejc-procurement-api-3.0.0-20251204.114052-58-sources.jar: com/ejianc/business/procurement/plan/vo/ExecutePlanVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.procurement.plan.vo.ExecutePlanDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 采购执行计划
 * 
 * @author generator
 * 
 */
public class ExecutePlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal ctrlTaxMny; // 控制含税总额
    private BigDecimal preTaxMny; // 预估含税总额
    private BigDecimal bidTaxMny; // 投标含税总额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String billCode; // 执行计划编号
    private String orgName; // 采购实施单位名称
    private String orgCode; // 采购实施单位编码
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    private String employeeName; // 经办人名称
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    private String memo; // 备注
    private String name; // 执行计划名称
    private String purchaseType; // 采购方式：1-带量；2-入围；3-框架
    private String purchaseStage; // 入围阶段：1-一阶段；2-二阶段
    private String stageOneResultName; // 一阶段入围计划结果（参照定标结果）
    private String purchasePlanCode; // 一阶段采购计划编码
    private Integer billState; // 单据状态
    private Integer permissionType; // 实施流程 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private Integer abnormalStatus; // 计划异常状态 1-正常，2-取消采购，3-暂停采购
    private Long orgId; // 采购实施单位Id
    private Long employeeId; // 经办人
    private Long stageOneResultId; // 一阶段入围计划结果id（参照定标结果）
    private Long purchasePlanId; // 一阶段采购计划id
    
    private List<ExecutePlanDetailVO> executePlanDetailList = new ArrayList<>(); // 采购执行计划-明细

    public BigDecimal getCtrlTaxMny() {
        return ctrlTaxMny;
    }

    public void setCtrlTaxMny(BigDecimal ctrlTaxMny) {
        this.ctrlTaxMny = ctrlTaxMny;
    }
    public BigDecimal getPreTaxMny() {
        return preTaxMny;
    }

    public void setPreTaxMny(BigDecimal preTaxMny) {
        this.preTaxMny = preTaxMny;
    }
    public BigDecimal getBidTaxMny() {
        return bidTaxMny;
    }

    public void setBidTaxMny(BigDecimal bidTaxMny) {
        this.bidTaxMny = bidTaxMny;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseStage() {
        return purchaseStage;
    }

    public void setPurchaseStage(String purchaseStage) {
        this.purchaseStage = purchaseStage;
    }
    public String getStageOneResultName() {
        return stageOneResultName;
    }

    public void setStageOneResultName(String stageOneResultName) {
        this.stageOneResultName = stageOneResultName;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public Integer getAbnormalStatus() {
        return abnormalStatus;
    }

    public void setAbnormalStatus(Integer abnormalStatus) {
        this.abnormalStatus = abnormalStatus;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getStageOneResultId() {
        return stageOneResultId;
    }

    public void setStageOneResultId(Long stageOneResultId) {
        this.stageOneResultId = stageOneResultId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    
     public List<ExecutePlanDetailVO> getExecutePlanDetailList() {
        return executePlanDetailList;
     }

     public void setExecutePlanDetailList(List<ExecutePlanDetailVO> executePlanDetailList) {
        this.executePlanDetailList = executePlanDetailList;
     }
}
